@@ -4,7 +4,7 @@ from typing import List
 import typer
 
 import cpdf.cat
-import cpdf.image_extractor
+import cpdf.extract_images
 import cpdf.up2
 
 
@@ -30,7 +30,7 @@ def common(
 
 @entry_point.command(name="extract-images")  # type: ignore[misc]
 def extract_images(pdf: Path) -> None:
-    cpdf.image_extractor.main(pdf)
+    cpdf.extract_images.main(pdf)
 
 
 @entry_point.command(name="2-up")  # type: ignore[misc]
@@ -48,4 +48,6 @@ def cat(
     cpdf.cat.main(filename, fn_pgrgs, output, verbose)
 
 
+up2.__doc__ = cpdf.up2.__doc__
+extract_images.__doc__ = cpdf.extract_images.__doc__
 cat.__doc__ = cpdf.cat.__doc__
